package models

type SmartSchPatient struct {
	ID         int64  `gorm:"column:id" json:"id" form:"id"`
	UserOrgId  int64  `gorm:"column:user_org_id" json:"user_org_id" form:"user_org_id"`
	Name       string `gorm:"column:name" json:"name" form:"name"`
	DialysisNo string `gorm:"column:dialysis_no" json:"dialysis_no" form:"dialysis_no"`

	SmartSchedule []*SmartSchedule `gorm:"-" json:"sch"`
}

func (SmartSchPatient) TableName() string {
	return "xt_patients"
}

type SmartSchTemplatePatient struct {
	ID         int64  `gorm:"column:id" json:"id" form:"id"`
	UserOrgId  int64  `gorm:"column:user_org_id" json:"user_org_id" form:"user_org_id"`
	Name       string `gorm:"column:name" json:"name" form:"name"`
	DialysisNo string `gorm:"column:dialysis_no" json:"dialysis_no" form:"dialysis_no"`

	XtPatientScheduleTemplateId []*XtPatientScheduleTemplateId
}

func (SmartSchTemplatePatient) TableName() string {
	return "xt_patients"
}

type SmartSchedule struct {
	ID                 int64              `gorm:"column:id" json:"id" form:"id"`
	UserOrgId          int64              `gorm:"column:user_org_id" json:"user_org_id" form:"user_org_id"`
	PartitionId        int64              `gorm:"column:partition_id" json:"partition_id" form:"partition_id"`
	BedId              int64              `gorm:"column:bed_id" json:"bed_id" form:"bed_id"`
	PatientId          int64              `gorm:"column:patient_id" json:"patient_id" form:"patient_id"`
	ScheduleDate       int64              `gorm:"column:schedule_date" json:"schedule_date" form:"schedule_date"`
	ScheduleType       int64              `gorm:"column:schedule_type" json:"schedule_type" form:"schedule_type"`
	ScheduleWeek       int64              `gorm:"column:schedule_week" json:"schedule_week" form:"schedule_week"`
	ModeId             int64              `gorm:"column:mode_id" json:"mode_id" form:"mode_id"`
	Status             int64              `gorm:"column:status" json:"status" form:"status"`
	CreatedTime        int64              `gorm:"column:created_time" json:"created_time" form:"created_time"`
	UpdatedTime        int64              `gorm:"column:updated_time" json:"updated_time" form:"updated_time"`
	IsExport           int64              `gorm:"column:is_export" json:"is_export" form:"is_export"`
	DeviceZone         DeviceZone         `json:"zone" gorm:"foreignkey:ID;AssociationForeignKey:PartitionId;"`
	DeviceNumber       DeviceNumber       `json:"number" gorm:"foreignkey:ID;AssociationForeignKey:BedId;"`
	SmSchDialysisOrder SmSchDialysisOrder `json:"order" gorm:"foreignkey:BedId,PatientId,DialysisDate;AssociationForeignKey:BedId,PatientId,ScheduleDate;"`
}

func (SmartSchedule) TableName() string {
	return "xt_schedule"
}

type XtPatientScheduleTemplateId struct {
	ID                            int64                            `gorm:"column:id" json:"id" form:"id"`
	OrgId                         int64                            `gorm:"column:org_id" json:"org_id" form:"org_id"`
	Status                        int64                            `gorm:"column:status" json:"status" form:"status"`
	Ctime                         int64                            `gorm:"column:ctime" json:"ctime" form:"ctime"`
	Mtime                         int64                            `gorm:"column:mtime" json:"mtime" form:"mtime"`
	Week                          int64                            `gorm:"column:week" json:"week" form:"week"`
	XtPatientScheduleTemplateItem []*XtPatientScheduleTemplateItem `gorm:"foreignkey:TemplateId;AssociationForeignKey:ID;" json:"template" form:"template"`
}

func (XtPatientScheduleTemplateId) TableName() string {
	return "xt_patient_schedule_template_id"
}

type XtPatientScheduleTemplateItem struct {
	ID             int64 `gorm:"column:id" json:"id" form:"id"`
	OrgId          int64 `gorm:"column:org_id" json:"org_id" form:"org_id"`
	TemplateId     int64 `gorm:"column:template_id" json:"template_id" form:"template_id"`
	DeviceNumberId int64 `gorm:"column:device_number_id" json:"device_number_id" form:"device_number_id"`
	PatientId      int64 `gorm:"column:patient_id" json:"patient_id" form:"patient_id"`
	TreatMode      int64 `gorm:"column:treat_mode" json:"treat_mode" form:"treat_mode"`
	Weekday        int64 `gorm:"column:weekday" json:"weekday" form:"weekday"`
	TimeType       int64 `gorm:"column:time_type" json:"time_type" form:"time_type"`
	Status         int64 `gorm:"column:status" json:"status" form:"status"`
	Ctime          int64 `gorm:"column:ctime" json:"ctime" form:"ctime"`
	Mtime          int64 `gorm:"column:mtime" json:"mtime" form:"mtime"`
	IsExport       int64 `gorm:"column:is_export" json:"is_export" form:"is_export"`
	ZoneId         int64 `gorm:"-" json:"zone_id" form:"zone_id"`
}

func (XtPatientScheduleTemplateItem) TableName() string {
	return "xt_patient_schedule_template_item"
}

type SmSchDialysisOrder struct {
	ID           int64  `gorm:"column:id" json:"id" form:"id"`
	DialysisDate int64  `gorm:"column:dialysis_date" json:"dialysis_date" form:"dialysis_date"`
	UserOrgId    int64  `gorm:"column:user_org_id" json:"user_org_id" form:"user_org_id"`
	PatientId    int64  `gorm:"column:patient_id" json:"patient_id" form:"patient_id"`
	Stage        int64  `gorm:"column:stage" json:"stage" form:"stage"`
	Remark       string `gorm:"column:remark" json:"remark" form:"remark"`
	BedId        int64  `gorm:"column:bed_id" json:"bed_id" form:"bed_id"`
	StartNurse   int64  `gorm:"column:start_nurse" json:"start_nurse" form:"start_nurse"`
	FinishNurse  int64  `gorm:"column:finish_nurse" json:"finish_nurse" form:"finish_nurse"`
	Status       int64  `gorm:"column:status" json:"status" form:"status"`
}

func (SmSchDialysisOrder) TableName() string {
	return "xt_dialysis_order"
}
