package service

import (
	"XT_New/models"
	"fmt"
	"github.com/jinzhu/gorm"
	"time"
)

func GetAppVersionByAppType(apptype int64) (*models.AppVersion, error) {
	var version models.AppVersion
	err := readDb.Model(&models.AppVersion{}).Where("app_type=?", apptype).First(&version).Error
	if err == gorm.ErrRecordNotFound {
		return nil, nil
	}

	if err != nil {
		return nil, err
	}
	return &version, nil
}

func GetAllAppOrg() ([]*models.OrgApp, error) {
	var app []*models.OrgApp
	err := readUserDb.Model(&models.OrgApp{}).Where("status = 1 AND org_id > 0").Group("org_id").Find(&app).Error
	if err == gorm.ErrRecordNotFound {
		return nil, nil
	}

	if err != nil {
		return nil, err
	}
	return app, nil
}

func GetSystemApp() ([]*models.OrgApp, error) {
	var app []*models.OrgApp
	err := readDb.Model(&models.OrgApp{}).Where("status = 1 AND org_id = 0 ").Find(&app).Error
	if err == gorm.ErrRecordNotFound {
		return nil, nil
	}

	if err != nil {
		return nil, err
	}
	return app, nil
}

func GetApp() ([]*models.OrgApp, error) {
	var app []*models.OrgApp
	err := readDb.Model(&models.OrgApp{}).Where("status = 1 AND org_id = 0").Find(&app).Error
	if err == gorm.ErrRecordNotFound {
		return nil, nil
	}

	if err != nil {
		return nil, err
	}
	return app, nil
}

func GetAppByType(orgID int64, app_type int) (*models.OrgApp, error) {
	var apps models.OrgApp
	err := readUserDb.Where("app_type = ? AND org_id = ? AND status = 1", app_type, orgID).First(&apps).Error
	if err != nil {
		return nil, err
	}
	return &apps, nil
}

func CreateOrgApp(app *models.OrgApp) {
	writeUserDb.Create(&app)

}

func GetAllUserRole(org_id int64) (appRole []*models.App_Role) {
	if org_id == 0 {
		readUserDb.Model(&models.App_Role{}).Where("status = 1").Find(&appRole)

	} else {
		readUserDb.Model(&models.App_Role{}).Where("status = 1 AND org_id = ? ", org_id).Find(&appRole)

	}
	return
}

func GetAllUserRoleByUserTypeOne(org_id int) (appRole []*models.App_Role) {
	readUserDb.Model(&models.App_Role{}).Where("status = 1 AND user_type = 1").Find(&appRole)
	return
}

func GetAllUserRoleByUserTypeOther() (appRole []*models.App_Role) {
	//app, _ := GetOrgApp(int64(org_id), 3)

	//if org_id == 0 {
	readUserDb.Model(&models.App_Role{}).Where("status = 1 AND user_type > 1").Find(&appRole)
	//
	//} else {
	//	readUserDb.Model(&models.App_Role{}).Where("status = 1 AND org_id = ?  AND user_type > 1 AND app_id = ? ", org_id, app.Id).Find(&appRole)
	//
	//}
	return
}

func FindRoleByUserTypeOne(org_id int64) (role models.Role) {
	readUserDb.Model(&models.Role{}).Where("status = 1 AND org_id = ? AND is_system = 2 AND role_name = '医生'", org_id).First(&role)
	return
}

func FindRoleByUserTypeTwo(org_id int64) (role models.Role) {
	readUserDb.Model(&models.Role{}).Where("status = 1 AND org_id = ? AND is_system = 3 AND role_name = '护士'", org_id).First(&role)
	return
}

func GetAllRole() ([]*models.Role, error) {
	var app []*models.Role
	err := readUserDb.Model(&models.Role{}).Where("status = 1 AND org_id > 0").Group("org_id").Find(&app).Error
	if err == gorm.ErrRecordNotFound {
		return nil, nil
	}
	if err != nil {
		return nil, err
	}
	return app, nil
}

func UpdateRoleIds(id int64, ids string) {
	writeUserDb.Model(&models.App_Role{}).Where("status = 1 AND id = ?", id).Updates(map[string]interface{}{"role_ids": ids, "mtime": time.Now().Unix()})

}

func GetOrgAppA(orgID int64, app_type int) (*models.OrgApp, error) {
	var apps models.OrgApp
	err := readUserDb.Where("app_type = ? AND org_id = ? AND status = 1", app_type, orgID).First(&apps).Error
	if err != nil {
		return nil, err
	}
	return &apps, nil
}

func GetOrgByIdB(orgID int64) (*models.Org, error) {
	var org models.Org
	err := readUserDb.Model(&models.Org{}).Where("id = ?", orgID).First(&org).Error
	if err != nil {
		if err == gorm.ErrRecordNotFound {
			return nil, nil
		} else {
			return nil, err
		}
	}
	return &org, nil
}

func GetOrgAppB(orgID int64, app_type int) (*models.OrgApp, error) {
	var apps models.OrgApp
	err := readUserDb.Where("app_type = ? AND org_id = ? AND status = 1", app_type, orgID).First(&apps).Error
	if err != nil {
		return nil, err
	}
	return &apps, nil
}

func CreateOrgRoleB(role *models.Role) (err error) {
	err = writeUserDb.Create(&role).Error
	return
}

func CreateRolePurviewB(purview *models.RolePurview) (err error) {
	err = writeUserDb.Create(&purview).Error
	return
}

func CreateFuncRolePurviewB(purview *models.SgjUserRoleFuncPurview) (err error) {
	err = writeUserDb.Create(&purview).Error
	return
}

func GetSystemRole(orgID int64) ([]*models.Role, error) {
	var roles []*models.Role
	err := readUserDb.Where(" org_id = ? AND status = 1 AND is_system > 1", orgID).First(&roles).Error
	if err != nil {
		return nil, err
	}
	return roles, nil
}

func HandleData() {
	var pe []*models.PredialysisEvaluation
	//readDb.Model(&models.DialysisPrescription{}).Where("user_org_id = 12 AND record_date <= 1587571200").Find(&prescription)
	//for _, item := range prescription {
	//	writeDb.Model(&models.AssessmentAfterDislysis{}).Where("user_org_id =12 AND assessment_date = ?", item.RecordDate).Updates(map[string]interface{}{"mtime": time.Now().Unix(), "actual_ultrafiltration": item.Ultrafiltration})
	//}
	readDb.Model(&models.PredialysisEvaluation{}).Where("status = 1 AND user_org_id = 9538 AND dialysis_order_id > 0").Find(&pe)

	for _, item := range pe {
		var sch models.Schedule
		err := readDb.Model(&models.Schedule{}).Where("status = 1 AND schedule_date = ? AND patient_id = ? AND user_org_id = 9538", item.AssessmentDate, item.PatientId).First(&sch).Error

		if err == nil {
			if sch.ID > 0 {
				order := &models.DialysisOrder{
					DialysisDate:   sch.ScheduleDate,
					UserOrgId:      9538,
					PatientId:      sch.PatientId,
					Stage:          2,
					BedID:          sch.BedId,
					StartNurse:     554,
					FinishNurse:    554,
					Status:         1,
					CreatedTime:    sch.ScheduleDate,
					UpdatedTime:    sch.ScheduleDate,
					StartTime:      sch.ScheduleDate,
					EndTime:        sch.ScheduleDate,
					PunctureNurse:  554,
					Creator:        554,
					Modifier:       554,
					FinishCreator:  554,
					FinishModifier: 554,
					SchedualType:   sch.ScheduleType,
				}
				writeDb.Create(&order)
			}
		}

	}

}

func FindAllOrgByImportType() (org []*models.Org, err error) {
	err = readUserDb.Model(&models.Org{}).Where("status =1 AND import = 0").Find(&org).Error
	return
}

func FindAllPrescription(org_id int64) (prescription []*models.DialysisPrescription, err error) {
	err = readDb.Model(&models.DialysisPrescription{}).Where("user_org_id=? AND status= 1 AND record_date >= 1593446400", org_id).Find(&prescription).Error
	return
}

func AddSigleDialysisBeforePre(before *models.DialysisBeforePrepare) {
	writeDb.Create(&before)
}

func GetAllHisDoctorInfo(org_id int64) (his []*models.HisDoctorAdviceInfo, err error) {
	err = readDb.Model(&models.HisDoctorAdviceInfo{}).Where("user_org_id = ? AND status = 1", org_id).Find(&his).Error
	return
}

func GetAllHisInfo(org_id int64) (his []*models.HisPrescriptionProject, err error) {
	err = readDb.Model(&models.HisPrescriptionProject{}).Where("user_org_id = ? AND status = 1", org_id).Find(&his).Error
	return
}

func UpDateHis(his *models.HisDoctorAdviceInfo) {
	writeDb.Save(&his)
}

func UpDateHis2(his *models.HisPrescriptionProject) {
	writeDb.Save(&his)
}

func GetAllHisOrder(org_id int64) (his []*models.HisOrder, err error) {
	err = readDb.Model(&models.HisOrder{}).Where("user_org_id = ? AND status = 1 AND order_status = 2 AND fa_piao_code = '' AND fa_piao_number = '' ", org_id).Find(&his).Error
	return
}

func GetAllHisOrderTwo(org_id int64) (his models.HisOrder, err error) {
	err = readDb.Model(&models.HisOrder{}).Where("user_org_id = ? AND status = 1 AND order_status = 2 AND fa_piao_code <> '' AND fa_piao_number <> '' ", org_id).Last(&his).Error
	return
}

func GetLastHisOrder() (his models.HisOrder, err error) {
	err = readDb.Model(&models.HisOrder{}).Where("user_org_id = 10106 AND status = 1 AND order_status = 2").Last(&his).Error
	return
}

type HisPrescriptionAdviceTemplate struct {
	ID                    int64   `gorm:"column:id" json:"id" form:"id"`
	UserOrgId             int64   `gorm:"column:user_org_id" json:"user_org_id" form:"user_org_id"`
	PatientId             int64   `gorm:"column:patient_id" json:"patient_id" form:"patient_id"`
	HisPatientId          int64   `gorm:"column:his_patient_id" json:"his_patient_id" form:"his_patient_id"`
	AdviceType            int64   `gorm:"column:advice_type" json:"advice_type" form:"advice_type"`
	AdviceDate            int64   `gorm:"column:advice_date" json:"advice_date" form:"advice_date"`
	StartTime             int64   `gorm:"column:start_time" json:"start_time" form:"start_time"`
	AdviceName            string  `gorm:"column:advice_name" json:"advice_name" form:"advice_name"`
	AdviceDesc            string  `gorm:"column:advice_desc" json:"advice_desc" form:"advice_desc"`
	ReminderDate          int64   `gorm:"column:reminder_date" json:"reminder_date" form:"reminder_date"`
	SingleDose            float64 `gorm:"column:single_dose" json:"single_dose" form:"single_dose"`
	SingleDoseUnit        string  `gorm:"column:single_dose_unit" json:"single_dose_unit" form:"single_dose_unit"`
	PrescribingNumber     float64 `gorm:"column:prescribing_number" json:"prescribing_number" form:"prescribing_number"`
	PrescribingNumberUnit string  `gorm:"column:prescribing_number_unit" json:"prescribing_number_unit" form:"prescribing_number_unit"`
	DeliveryWay           string  `gorm:"column:delivery_way" json:"delivery_way" form:"delivery_way"`
	ExecutionFrequency    string  `gorm:"column:execution_frequency" json:"execution_frequency" form:"execution_frequency"`
	AdviceDoctor          int64   `gorm:"column:advice_doctor" json:"advice_doctor" form:"advice_doctor"`
	Status                int64   `gorm:"column:status" json:"status" form:"status"`
	CreatedTime           int64   `gorm:"column:created_time" json:"created_time" form:"created_time"`
	UpdatedTime           int64   `gorm:"column:updated_time" json:"updated_time" form:"updated_time"`
	AdviceAffirm          string  `gorm:"column:advice_affirm" json:"advice_affirm" form:"advice_affirm"`
	Remark                string  `gorm:"column:remark" json:"remark" form:"remark"`
	StopTime              int64   `gorm:"column:stop_time" json:"stop_time" form:"stop_time"`
	StopReason            string  `gorm:"column:stop_reason" json:"stop_reason" form:"stop_reason"`
	StopDoctor            int64   `gorm:"column:stop_doctor" json:"stop_doctor" form:"stop_doctor"`
	StopState             int64   `gorm:"column:stop_state" json:"stop_state" form:"stop_state"`
	ParentId              int64   `gorm:"column:parent_id" json:"parent_id" form:"parent_id"`
	ExecutionTime         int64   `gorm:"column:execution_time" json:"execution_time" form:"execution_time"`
	ExecutionStaff        int64   `gorm:"column:execution_staff" json:"execution_staff" form:"execution_staff"`
	ExecutionState        int64   `gorm:"column:execution_state" json:"execution_state" form:"execution_state"`
	Checker               int64   `gorm:"column:checker" json:"checker" form:"checker"`
	RecordDate            int64   `gorm:"column:record_date" json:"record_date" form:"record_date"`
	DialysisOrderId       int64   `gorm:"column:dialysis_order_id" json:"dialysis_order_id" form:"dialysis_order_id"`
	CheckTime             int64   `gorm:"column:check_time" json:"check_time" form:"check_time"`
	CheckState            int64   `gorm:"column:check_state" json:"check_state" form:"check_state"`
	DrugSpec              float64 `gorm:"column:drug_spec" json:"drug_spec" form:"drug_spec"`
	DrugSpecUnit          string  `gorm:"column:drug_spec_unit" json:"drug_spec_unit" form:"drug_spec_unit"`
	Groupno               int64   `gorm:"column:groupno" json:"groupno" form:"groupno"`
	RemindType            int64   `gorm:"column:remind_type" json:"remind_type" form:"remind_type"`
	FrequencyType         int64   `gorm:"column:frequency_type" json:"frequency_type" form:"frequency_type"`
	DayCount              int64   `gorm:"column:day_count" json:"day_count" form:"day_count"`
	WeekDay               string  `gorm:"column:week_day" json:"week_day" form:"week_day"`
	TemplateId            string  `gorm:"column:template_id" json:"template_id" form:"template_id"`
	Modifier              int64   `gorm:"column:modifier" json:"modifier" form:"modifier"`
	DrugId                int64   `gorm:"column:drug_id" json:"drug_id" form:"drug_id"`
	Price                 float64 `gorm:"column:price" json:"price" form:"price"`
	PrescriptionId        int64   `gorm:"column:prescription_id" json:"prescription_id" form:"prescription_id"`
	MedListCodg           string  `gorm:"column:med_list_codg" json:"med_list_codg" form:"med_list_codg"`
	FeedetlSn             string  `gorm:"column:feedetl_sn" json:"feedetl_sn" form:"feedetl_sn"`
	Day                   int64   `gorm:"column:day" json:"day" form:"day"`
	Diagnosis             int64   `gorm:"column:diagnosis" json:"diagnosis" form:"diagnosis"`
	HospApprFlag          int64   `gorm:"column:hosp_appr_flag" json:"hosp_appr_flag" form:"hosp_appr_flag"`
	LmtUsedFlag           int64   `gorm:"column:lmt_used_flag" json:"lmt_used_flag" form:"lmt_used_flag"`
}

func (HisPrescriptionAdviceTemplate) TableName() string {
	return "his_prescription_advice_template"
}

type HisPrescriptionInfoTemplateTwo struct {
	ID                            int64                           `gorm:"column:id" json:"id" form:"id"`
	UserOrgId                     int64                           `gorm:"column:user_org_id" json:"user_org_id" form:"user_org_id"`
	RecordDate                    int64                           `gorm:"column:record_date" json:"record_date" form:"record_date"`
	PatientId                     int64                           `gorm:"column:patient_id" json:"patient_id" form:"patient_id"`
	Status                        int64                           `gorm:"column:status" json:"status" form:"status"`
	Ctime                         int64                           `gorm:"column:ctime" json:"ctime" form:"ctime"`
	Mtime                         int64                           `gorm:"column:mtime" json:"mtime" form:"mtime"`
	Type                          int64                           `gorm:"column:type" json:"type" form:"type"`
	Creator                       int64                           `gorm:"column:creator" json:"creator" form:"creator"`
	Modifier                      int64                           `gorm:"column:modifier" json:"modifier" form:"modifier"`
	PType                         int64                           `gorm:"column:p_type" json:"p_type" form:"p_type"`
	PTemplateId                   int64                           `gorm:"column:p_template_id" json:"p_template_id" form:"p_template_id"`
	HisPrescriptionAdviceTemplate []HisPrescriptionAdviceTemplate `gorm:"ForeignKey:PrescriptionId;AssociationForeignKey:ID" json:"advices"`
	MedType                       string                          `gorm:"column:med_type" json:"med_type" form:"med_type"`
}

func (HisPrescriptionInfoTemplateTwo) TableName() string {
	return "his_prescription_info_template"
}

func GetHisPrescriptionTemplateTwo() (prescription []*HisPrescriptionInfoTemplateTwo, err error) {
	err = readDb.Model(&HisPrescriptionInfoTemplateTwo{}).
		Preload("HisPrescriptionAdviceTemplate", func(db *gorm.DB) *gorm.DB {
			return db.Where("status = 1")
		}).
		Where("status = 1 ").
		Find(&prescription).Error
	return
}

func SaveAdviceTemplate(advice HisPrescriptionAdviceTemplate) {
	writeDb.Save(&advice)
}

func GetAllPT(org_id int64) (his []*models.HisPrescriptionTemplate, err error) {
	err = readDb.Model(&models.HisPrescriptionTemplate{}).Where("user_org_id = ? AND status = 1", org_id).Find(&his).Error
	return
}

type HisPrescriptionProjectTemplate struct {
	ID                 int64   `gorm:"column:id" json:"id" form:"id"`
	ProjectId          int64   `gorm:"column:project_id" json:"project_id" form:"project_id"`
	Price              float64 `gorm:"column:price" json:"price" form:"price"`
	UserOrgId          int64   `gorm:"column:user_org_id" json:"user_org_id" form:"user_org_id"`
	Status             int64   `gorm:"column:status" json:"status" form:"status"`
	Ctime              int64   `gorm:"column:ctime" json:"ctime" form:"ctime"`
	Mtime              int64   `gorm:"column:mtime" json:"mtime" form:"mtime"`
	PatientId          int64   `gorm:"column:patient_id" json:"patient_id" form:"patient_id"`
	HisPatientId       int64   `gorm:"column:his_patient_id" json:"his_patient_id" form:"his_patient_id"`
	RecordDate         int64   `gorm:"column:record_date" json:"record_date" form:"record_date"`
	Count              string  `gorm:"column:count" json:"count" form:"count"`
	FeedetlSn          string  `gorm:"column:feedetl_sn" json:"feedetl_sn" form:"feedetl_sn"`
	MedListCodg        string  `gorm:"column:med_list_codg" json:"med_list_codg" form:"med_list_codg"`
	SingleDose         string  `gorm:"column:single_dose" json:"single_dose" form:"single_dose"`
	DeliveryWay        string  `gorm:"column:delivery_way" json:"delivery_way" form:"delivery_way"`
	ExecutionFrequency string  `gorm:"column:execution_frequency" json:"execution_frequency" form:"execution_frequency"`
	Day                string  `gorm:"column:day" json:"day" form:"day"`
	Remark             string  `gorm:"column:remark" json:"remark" form:"remark"`
	Unit               string  `gorm:"column:unit" json:"unit" form:"unit"`
	Type               int64   `gorm:"column:type" json:"type" form:"type"`
	PrescriptionId     int64   `gorm:"column:prescription_id" json:"prescription_id" form:"prescription_id"`
	FrequencyType      int64   `gorm:"column:frequency_type" json:"frequency_type" form:"frequency_type"`
	DayCount           int64   `gorm:"column:day_count" json:"day_count" form:"day_count"`
	WeekDay            string  `gorm:"column:week_day" json:"week_day" form:"week_day"`
}

func (HisPrescriptionProjectTemplate) TableName() string {
	return "his_prescription_project_template"
}

type HisPrescriptionInfoTemplateTHree struct {
	ID                             int64                            `gorm:"column:id" json:"id" form:"id"`
	UserOrgId                      int64                            `gorm:"column:user_org_id" json:"user_org_id" form:"user_org_id"`
	RecordDate                     int64                            `gorm:"column:record_date" json:"record_date" form:"record_date"`
	PatientId                      int64                            `gorm:"column:patient_id" json:"patient_id" form:"patient_id"`
	Status                         int64                            `gorm:"column:status" json:"status" form:"status"`
	Ctime                          int64                            `gorm:"column:ctime" json:"ctime" form:"ctime"`
	Mtime                          int64                            `gorm:"column:mtime" json:"mtime" form:"mtime"`
	Type                           int64                            `gorm:"column:type" json:"type" form:"type"`
	Creator                        int64                            `gorm:"column:creator" json:"creator" form:"creator"`
	Modifier                       int64                            `gorm:"column:modifier" json:"modifier" form:"modifier"`
	PType                          int64                            `gorm:"column:p_type" json:"p_type" form:"p_type"`
	PTemplateId                    int64                            `gorm:"column:p_template_id" json:"p_template_id" form:"p_template_id"`
	HisPrescriptionAdviceTemplate  []HisPrescriptionAdviceTemplate  `gorm:"ForeignKey:PrescriptionId;AssociationForeignKey:ID" json:"advices"`
	HisPrescriptionProjectTemplate []HisPrescriptionProjectTemplate `gorm:"ForeignKey:PrescriptionId;AssociationForeignKey:ID" json:"project"`
	MedType                        string                           `gorm:"column:med_type" json:"med_type" form:"med_type"`
}

func (HisPrescriptionInfoTemplateTHree) TableName() string {
	return "his_prescription_info_template"
}

func GetAllPTInfo(org_id int64, p_template_id int64) (his []*HisPrescriptionInfoTemplateTHree, err error) {
	err = readDb.Model(&HisPrescriptionInfoTemplateTHree{}).Preload("HisPrescriptionAdviceTemplate", func(db *gorm.DB) *gorm.DB {
		return db.Where("status = 1")
	}).Preload("HisPrescriptionProjectTemplate", func(db *gorm.DB) *gorm.DB {
		return db.Where("status = 1")
	}).Where("user_org_id = ? AND status = 1 AND p_template_id = ?", org_id, p_template_id).Find(&his).Error
	return
}

func GetAllInfo(org_id int64, project_id int64) (his []*HisPrescriptionProjectTemplate, err error) {
	err = readDb.Model(&HisPrescriptionProjectTemplate{}).Where("user_org_id = ? AND status = 1 AND project_id = ? ", org_id, project_id).Find(&his).Error
	return
}
func UpdateStatus(project_id int64, p_id int64) {
	writeDb.Model(&HisPrescriptionProjectTemplate{}).Where("id = ?", project_id).Updates(map[string]interface{}{"status": 0})
	writeDb.Model(&HisPrescriptionInfoTemplateTwo{}).Where("id = ?", p_id).Updates(map[string]interface{}{"status": 0})
}

func SaveOrder(order *models.HisOrder) {
	writeDb.Save(&order)
}

func GetAllPrivateHis(org_id int64) (his []*models.HisPatient) {
	readDb.Model(&models.HisPatient{}).Where("user_org_id = ? AND balance_accounts_type = 2 AND status = 1", org_id).Find(&his)
	return
}

func SaveHis(his *models.HisPatient) {
	writeDb.Save(his)
	return
}

func GetAllProjectPrescription() (pre []*models.HisPrescription) {
	readDb.Model(&models.HisPrescription{}).Where("user_org_id = 10215 AND status = 1 AND type = 2 AND order_status = 1 AND record_date >= 1659283200").Find(&pre)
	return
}

func GetAllProject(id int64) (pre []*models.HisPrescriptionProject) {
	readDb.Model(&models.HisPrescriptionProject{}).Where("user_org_id = 10215 AND status = 1 AND project_id = 1735  AND prescription_id = ?", id).Find(&pre)
	return
}

//func GetHisOrderDetailByNumberTwo(order_number string, org_id int64) (order []*HisOrderInfo, err error) {
//	readDb.Model(&models.Patients{})
//
//	err = readDb.Model(&HisOrderInfo{}).Where("order_number = ? AND status = 1", order_number).Preload("HisPrescriptionProject", func(db *gorm.DB) *gorm.DB {
//		return db.Where("status = 1 AND user_org_id = ?", org_id).Preload("VMHisPrescriptionTwo", "status = 1 AND user_org_id = ?", org_id).Preload("VMHisProject", "status = 1 AND user_org_id = ?", org_id).Preload("VMGoodInfo", "status = 1 AND org_id = ?", org_id)
//	}).Preload("HisDoctorAdviceInfo", func(db *gorm.DB) *gorm.DB {
//		return db.Where("status = 1 AND user_org_id = ?", org_id).Preload("VMHisPrescriptionTwo", "status = 1 AND user_org_id = ?", org_id).Preload("Drug", "status = 1 AND org_id = ?", org_id)
//	}).Find(&order).Error
//	return
//}

type HisOrderTen struct {
	ID                    int64                 `gorm:"column:id" json:"id" form:"id"`
	UserOrgId             int64                 `gorm:"column:user_org_id" json:"user_org_id" form:"user_org_id"`
	HisPatientId          int64                 `gorm:"column:his_patient_id" json:"his_patient_id" form:"his_patient_id"`
	SettleAccountsDate    int64                 `gorm:"column:settle_accounts_date" json:"settle_accounts_date" form:"settle_accounts_date"`
	Ctime                 int64                 `gorm:"column:ctime" json:"ctime" form:"ctime"`
	Mtime                 int64                 `gorm:"column:mtime" json:"mtime" form:"mtime"`
	Status                int64                 `gorm:"column:status" json:"status" form:"status"`
	Number                string                `gorm:"column:number" json:"number" form:"number"`
	PatientId             int64                 `gorm:"column:patient_id" json:"patient_id" form:"patient_id"`
	Infcode               int64                 `gorm:"column:infcode" json:"infcode" form:"infcode"`
	WarnMsg               string                `gorm:"column:warn_msg" json:"warn_msg" form:"warn_msg"`
	Cainfo                string                `gorm:"column:cainfo" json:"cainfo" form:"cainfo"`
	ErrMsg                string                `gorm:"column:err_msg" json:"err_msg" form:"err_msg"`
	RespondTime           string                `gorm:"column:respond_time" json:"respond_time" form:"respond_time"`
	InfRefmsgid           string                `gorm:"column:inf_refmsgid" json:"inf_refmsgid" form:"inf_refmsgid"`
	OrderStatus           int64                 `gorm:"column:order_status" json:"order_status" form:"order_status"`
	MdtrtId               string                `gorm:"column:mdtrt_id" json:"mdtrt_id" form:"mdtrt_id"`
	SetlId                string                `gorm:"column:setl_id" json:"setl_id" form:"setl_id"`
	PsnNo                 string                `gorm:"column:psn_no" json:"psn_no" form:"psn_no"`
	PsnName               string                `gorm:"column:psn_name" json:"psn_name" form:"psn_name"`
	PsnCertType           string                `gorm:"column:psn_cert_type" json:"psn_cert_type" form:"psn_cert_type"`
	Certno                string                `gorm:"column:certno" json:"certno" form:"certno"`
	Gend                  string                `gorm:"column:gend" json:"gend" form:"gend"`
	Naty                  string                `gorm:"column:naty" json:"naty" form:"naty"`
	Brdy                  time.Time             `gorm:"column:brdy" json:"brdy" form:"brdy"`
	Age                   float64               `gorm:"column:age" json:"age" form:"age"`
	Insutype              string                `gorm:"column:insutype" json:"insutype" form:"insutype"`
	PsnType               string                `gorm:"column:psn_type" json:"psn_type" form:"psn_type"`
	CvlservFlag           string                `gorm:"column:cvlserv_flag" json:"cvlserv_flag" form:"cvlserv_flag"`
	SetlTime              string                `gorm:"column:setl_time" json:"setl_time" form:"setl_time"`
	MdtrtCertType         string                `gorm:"column:mdtrt_cert_type" json:"mdtrt_cert_type" form:"mdtrt_cert_type"`
	MedType               string                `gorm:"column:med_type" json:"med_type" form:"med_type"`
	MedfeeSumamt          float64               `gorm:"column:medfee_sumamt" json:"medfee_sumamt" form:"medfee_sumamt"`
	FulamtOwnpayAmt       float64               `gorm:"column:fulamt_ownpay_amt" json:"fulamt_ownpay_amt" form:"fulamt_ownpay_amt"`
	OverlmtSelfPay        float64               `gorm:"column:overlmt_self_pay" json:"overlmt_self_pay" form:"overlmt_self_pay"`
	PreselfpayAmt         float64               `gorm:"column:preselfpay_amt" json:"preselfpay_amt" form:"preselfpay_amt"`
	InscpScpAmt           float64               `gorm:"column:inscp_scp_amt" json:"inscp_scp_amt" form:"inscp_scp_amt"`
	ActPayDedc            float64               `gorm:"column:act_pay_dedc" json:"act_pay_dedc" form:"act_pay_dedc"`
	HifpPay               float64               `gorm:"column:hifp_pay" json:"hifp_pay" form:"hifp_pay"`
	CvlservPay            float64               `gorm:"column:cvlserv_pay" json:"cvlserv_pay" form:"cvlserv_pay"`
	PoolPropSelfpay       float64               `gorm:"column:pool_prop_selfpay" json:"pool_prop_selfpay" form:"pool_prop_selfpay"`
	HifesPay              float64               `gorm:"column:hifes_pay" json:"hifes_pay" form:"hifes_pay"`
	HifmiPay              float64               `gorm:"column:hifmi_pay" json:"hifmi_pay" form:"hifmi_pay"`
	HifobPay              float64               `gorm:"column:hifob_pay" json:"hifob_pay" form:"hifob_pay"`
	MafPay                float64               `gorm:"column:maf_pay" json:"maf_pay" form:"maf_pay"`
	OthPay                float64               `gorm:"column:oth_pay" json:"oth_pay" form:"oth_pay"`
	FundPaySumamt         float64               `gorm:"column:fund_pay_sumamt" json:"fund_pay_sumamt" form:"fund_pay_sumamt"`
	PsnPartAmt            float64               `gorm:"column:psn_part_amt" json:"psn_part_amt" form:"psn_part_amt"`
	AcctPay               float64               `gorm:"column:acct_pay" json:"acct_pay" form:"acct_pay"`
	PsnCashPay            float64               `gorm:"column:psn_cash_pay" json:"psn_cash_pay" form:"psn_cash_pay"`
	HospPartAmt           float64               `gorm:"column:hosp_part_amt" json:"hosp_part_amt" form:"hosp_part_amt"`
	Balc                  float64               `gorm:"column:balc" json:"balc" form:"balc"`
	AcctMulaidPay         float64               `gorm:"column:acct_mulaid_pay" json:"acct_mulaid_pay" form:"acct_mulaid_pay"`
	MedinsSetlId          string                `gorm:"column:medins_setl_id" json:"medins_setl_id" form:"medins_setl_id"`
	ClrOptins             string                `gorm:"column:clr_optins" json:"clr_optins" form:"clr_optins"`
	ClrWay                string                `gorm:"column:clr_way" json:"clr_way" form:"clr_way"`
	ClrType               string                `gorm:"column:clr_type" json:"clr_type" form:"clr_type"`
	SetlDetail            string                `gorm:"column:setl_detail" json:"setl_detail" form:"setl_detail"`
	IsMedicineInsurance   int64                 `gorm:"column:is_medicine_insurance" json:"is_medicine_insurance" form:"is_medicine_insurance"`
	PayWay                int64                 `gorm:"column:pay_way" json:"pay_way" form:"pay_way"`
	PayPrice              float64               `gorm:"column:pay_price" json:"pay_price" form:"pay_price"`
	PayCardNo             string                `gorm:"column:pay_card_no" json:"pay_card_no" form:"pay_card_no"`
	DiscountPrice         float64               `gorm:"column:discount_price" json:"discount_price" form:"discount_price"`
	PreferentialPrice     float64               `gorm:"column:preferential_price" json:"preferential_price" form:"preferential_price"`
	RealityPrice          float64               `gorm:"column:reality_price" json:"reality_price" form:"reality_price"`
	FoundPrice            float64               `gorm:"column:found_price" json:"found_price" form:"found_price"`
	MedicalInsurancePrice float64               `gorm:"column:medical_insurance_price" json:"medical_insurance_price" form:"medical_insurance_price"`
	PrivatePrice          float64               `gorm:"column:private_price" json:"private_price" form:"private_price"`
	DepartmentName        string                `gorm:"-" json:"department_name" form:"department_name"`
	DoctorName            string                `gorm:"-" json:"doctor_name" form:"doctor_name"`
	Creator               int64                 `gorm:"column:creator" json:"creator" form:"creator"`
	PType                 int64                 `gorm:"column:p_type" json:"p_type" form:"p_type"`
	Decimal               float64               `gorm:"column:decimal" json:"decimal" form:"decimal"`
	HisPrescriptionTen    []*HisPrescriptionTen `gorm:"ForeignKey:BatchNumber;AssociationForeignKey:Number" json:"info"`
	Patients              Patients              `gorm:"ForeignKey:PatientId;AssociationForeignKey:ID" json:"patient"`
}

func (HisOrderTen) TableName() string {
	return "his_order"
}

type HisPrescriptionTen struct {
	ID                        int64                        `gorm:"column:id" json:"id" form:"id"`
	UserOrgId                 int64                        `gorm:"column:user_org_id" json:"user_org_id" form:"user_org_id"`
	RecordDate                int64                        `gorm:"column:record_date" json:"record_date" form:"record_date"`
	PatientId                 int64                        `gorm:"column:patient_id" json:"patient_id" form:"patient_id"`
	HisPatientId              int64                        `gorm:"column:his_patient_id" json:"his_patient_id" form:"his_patient_id"`
	Status                    int64                        `gorm:"column:status" json:"status" form:"status"`
	Ctime                     int64                        `gorm:"column:ctime" json:"ctime" form:"ctime"`
	Mtime                     int64                        `gorm:"column:mtime" json:"mtime" form:"mtime"`
	Number                    string                       `gorm:"column:number" json:"number" form:"number"`
	Type                      int64                        `gorm:"column:type" json:"type" form:"type"`
	Doctor                    string                       `gorm:"column:doctor" json:"doctor" form:"doctor"`
	Creator                   int64                        `gorm:"column:creator" json:"creator" form:"creator"`
	Modifier                  int64                        `gorm:"column:modifier" json:"modifier" form:"modifier"`
	OrderStatus               int64                        `gorm:"column:order_status" json:"order_status" form:"order_status"`
	PreTime                   int64                        `gorm:"column:pre_time" json:"pre_time" form:"pre_time"`
	BatchNumber               string                       `gorm:"column:batch_number" json:"batch_number" form:"batch_number"`
	PrescriptionNumber        string                       `gorm:"column:prescription_number" json:"prescription_number" form:"prescription_number"`
	Patients                  Patients                     `gorm:"ForeignKey:PatientId;AssociationForeignKey:ID" json:"patient"`
	HisDoctorAdviceInfoTen    []*HisDoctorAdviceInfoTen    `gorm:"ForeignKey:PrescriptionId;AssociationForeignKey:ID" json:"advices"`
	HisPrescriptionProjectTen []*HisPrescriptionProjectTen `gorm:"ForeignKey:PrescriptionId;AssociationForeignKey:ID" json:"project"`
	Total                     string                       `gorm:"-" json:"total" form:"total"`
	PType                     int64                        `gorm:"column:p_type" json:"p_type" form:"p_type"`
	MedType                   string                       `gorm:"column:med_type" json:"med_type" form:"med_type"`
	IsMedicine                int64                        `gorm:"column:is_medicine" json:"is_medicine" form:"is_medicine"`
}

func (HisPrescriptionTen) TableName() string {
	return "his_prescription"
}

func GetHisOrderDetailThree() (order []*HisOrderTen, err error) {
	err = readDb.Model(&HisOrderTen{}).Preload("Patients", "status = 1").Preload("HisPrescriptionTen", func(db *gorm.DB) *gorm.DB {
		return db.Where("status = 1").Preload("HisPrescriptionProjectTen", func(db *gorm.DB) *gorm.DB {
			return db.Where("status = 1").Preload("VMHisProject", "status = 1").Preload("VMGoodInfo", "status = 1")
		}).Preload("HisDoctorAdviceInfoTen", func(db *gorm.DB) *gorm.DB {
			return db.Where("status = 1").Preload("Drug", "status = 1")
		})
	}).Where("settle_accounts_date >= 1659283200 AND settle_accounts_date <= 1661788800 AND status = 1 AND order_status =2 and p_type = 1 AND user_org_id = 10215").Find(&order).Order("patient_id").Error
	return
}

type HisDoctorAdviceInfoTen struct {
	ID                    int64   `gorm:"column:id" json:"id" form:"id"`
	UserOrgId             int64   `gorm:"column:user_org_id" json:"user_org_id" form:"user_org_id"`
	PatientId             int64   `gorm:"column:patient_id" json:"patient_id" form:"patient_id"`
	AdviceDate            int64   `gorm:"column:advice_date" json:"advice_date" form:"advice_date"`
	AdviceName            string  `gorm:"column:advice_name" json:"advice_name" form:"advice_name"`
	AdviceDesc            string  `gorm:"column:advice_desc" json:"advice_desc" form:"advice_desc"`
	SingleDose            float64 `gorm:"column:single_dose" json:"single_dose" form:"single_dose"`
	SingleDoseUnit        string  `gorm:"column:single_dose_unit" json:"single_dose_unit" form:"single_dose_unit"`
	PrescribingNumber     float64 `gorm:"column:prescribing_number" json:"prescribing_number" form:"prescribing_number"`
	PrescribingNumberUnit string  `gorm:"column:prescribing_number_unit" json:"prescribing_number_unit" form:"prescribing_number_unit"`
	DeliveryWay           string  `gorm:"column:delivery_way" json:"delivery_way" form:"delivery_way"`
	ExecutionFrequency    string  `gorm:"column:execution_frequency" json:"execution_frequency" form:"execution_frequency"`
	Status                int64   `gorm:"column:status" json:"status" form:"status"`
	CreatedTime           int64   `gorm:"column:created_time" json:"created_time" form:"created_time"`
	RecordDate            int64   `gorm:"column:record_date" json:"record_date" form:"record_date"`
	DrugSpec              float64 `gorm:"column:drug_spec" json:"drug_spec" form:"drug_spec"`
	DrugSpecUnit          string  `gorm:"column:drug_spec_unit" json:"drug_spec_unit" form:"drug_spec_unit"`
	PrescriptionId        int64   `gorm:"column:prescription_id" json:"prescription_id" form:"prescription_id"`

	Price                float64 `gorm:"column:price" json:"price" form:"price"`
	DrugId               int64   `gorm:"column:drug_id" json:"drug_id" form:"drug_id"`
	Drug                 Drug    `gorm:"ForeignKey:ID;AssociationForeignKey:DrugId" json:"drug"`
	IsMedicine           int64   `gorm:"column:is_medicine" json:"is_medicine" form:"is_medicine"`
	ExecutionFrequencyId int64   `gorm:"column:execution_frequency_id" json:"execution_frequency_id" form:"execution_frequency_id"`
}

func (HisDoctorAdviceInfoTen) TableName() string {
	return "his_doctor_advice_info"
}

type HisPrescriptionProjectTen struct {
	ID                 int64        `gorm:"column:id" json:"id" form:"id"`
	ProjectId          int64        `gorm:"column:project_id" json:"project_id" form:"project_id"`
	Price              float64      `gorm:"column:price" json:"price" form:"price"`
	UserOrgId          int64        `gorm:"column:user_org_id" json:"user_org_id" form:"user_org_id"`
	Status             int64        `gorm:"column:status" json:"status" form:"status"`
	Ctime              int64        `gorm:"column:ctime" json:"ctime" form:"ctime"`
	Mtime              int64        `gorm:"column:mtime" json:"mtime" form:"mtime"`
	PatientId          int64        `gorm:"column:patient_id" json:"patient_id" form:"patient_id"`
	HisPatientId       int64        `gorm:"column:his_patient_id" json:"his_patient_id" form:"his_patient_id"`
	RecordDate         int64        `gorm:"column:record_date" json:"record_date" form:"record_date"`
	PrescriptionId     int64        `gorm:"column:prescription_id" json:"prescription_id" form:"prescription_id"`
	Count              string       `gorm:"column:count" json:"count" form:"count"`
	FeedetlSn          string       `gorm:"column:feedetl_sn" json:"feedetl_sn" form:"feedetl_sn"`
	MedListCodg        string       `gorm:"column:med_list_codg" json:"med_list_codg" form:"med_list_codg"`
	SingleDose         string       `gorm:"column:single_dose" json:"single_dose" form:"single_dose"`
	DeliveryWay        string       `gorm:"column:delivery_way" json:"delivery_way" form:"delivery_way"`
	ExecutionFrequency string       `gorm:"column:execution_frequency" json:"execution_frequency" form:"execution_frequency"`
	Day                string       `gorm:"column:day" json:"day" form:"day"`
	VMHisProject       VMHisProject `gorm:"ForeignKey:ProjectId;AssociationForeignKey:ID" json:"project"`
	VMGoodInfo         VMGoodInfo   `gorm:"ForeignKey:ProjectId;AssociationForeignKey:ID" json:"good_info"`
	Remark             string       `gorm:"column:remark" json:"remark" form:"remark"`
	Unit               string       `gorm:"column:unit" json:"unit" form:"unit"`
	Type               int64        `gorm:"column:type" json:"type" form:"type"`
	Doctor             int64        `gorm:"column:doctor" json:"doctor" form:"doctor"`
	ExecutionTime      int64        `gorm:"column:execution_time" json:"execution_time" form:"execution_time"`
	ExecutionStaff     int64        `gorm:"column:execution_staff" json:"execution_staff" form:"execution_staff"`
	ExecutionState     int64        `gorm:"column:execution_state" json:"execution_state" form:"execution_state"`
	CheckTime          int64        `gorm:"column:check_time" json:"check_time" form:"check_time"`
	CheckState         int64        `gorm:"column:check_state" json:"check_state" form:"check_state"`
	Checker            int64        `gorm:"column:checker" json:"checker" form:"checker"`
	StartTime          int64        `gorm:"column:start_time" json:"start_time" form:"start_time"`
	TeamId             int64        `gorm:"column:team_id" json:"team_id" form:"team_id"`

	FrequencyType        int64  `gorm:"column:frequency_type" json:"frequency_type" form:"frequency_type"`
	DayCount             int64  `gorm:"column:day_count" json:"day_count" form:"day_count"`
	WeekDay              string `gorm:"column:week_day" json:"week_day" form:"week_day"`
	ExecutionFrequencyId int64  `gorm:"column:execution_frequency_id" json:"execution_frequency_id" form:"execution_frequency_id"`
}

func (HisPrescriptionProjectTen) TableName() string {
	return "his_prescription_project"
}

func GetHisPatient11111(orgid int64) (paitent []*models.HisHospitalCheckRecord, err error) {
	err = XTReadDB().Model(&paitent).Where("user_org_id = ?  and status = 1 AND in_hosptial_time >= '2022-11-01 00:00:00' AND in_hosptial_time <= '2022-11-30 23:59:59'", orgid).Find(&paitent).Error
	return paitent, err
}

func SaveHP(paitent *models.HisHospitalCheckRecord) {
	writeDb.Save(&paitent)

}

type HisOrder9504 struct {
	ID                    int64     `gorm:"column:id" json:"id" form:"id"`
	UserOrgId             int64     `gorm:"column:user_org_id" json:"user_org_id" form:"user_org_id"`
	HisPatientId          int64     `gorm:"column:his_patient_id" json:"his_patient_id" form:"his_patient_id"`
	SettleAccountsDate    int64     `gorm:"column:settle_accounts_date" json:"settle_accounts_date" form:"settle_accounts_date"`
	Ctime                 int64     `gorm:"column:ctime" json:"ctime" form:"ctime"`
	Mtime                 int64     `gorm:"column:mtime" json:"mtime" form:"mtime"`
	Status                int64     `gorm:"column:status" json:"status" form:"status"`
	Number                string    `gorm:"column:number" json:"number" form:"number"`
	PatientId             int64     `gorm:"column:patient_id" json:"patient_id" form:"patient_id"`
	Infcode               int64     `gorm:"column:infcode" json:"infcode" form:"infcode"`
	WarnMsg               string    `gorm:"column:warn_msg" json:"warn_msg" form:"warn_msg"`
	Cainfo                string    `gorm:"column:cainfo" json:"cainfo" form:"cainfo"`
	ErrMsg                string    `gorm:"column:err_msg" json:"err_msg" form:"err_msg"`
	RespondTime           string    `gorm:"column:respond_time" json:"respond_time" form:"respond_time"`
	InfRefmsgid           string    `gorm:"column:inf_refmsgid" json:"inf_refmsgid" form:"inf_refmsgid"`
	OrderStatus           int64     `gorm:"column:order_status" json:"order_status" form:"order_status"`
	MdtrtId               string    `gorm:"column:mdtrt_id" json:"mdtrt_id" form:"mdtrt_id"`
	SetlId                string    `gorm:"column:setl_id" json:"setl_id" form:"setl_id"`
	PsnNo                 string    `gorm:"column:psn_no" json:"psn_no" form:"psn_no"`
	PsnName               string    `gorm:"column:psn_name" json:"psn_name" form:"psn_name"`
	PsnCertType           string    `gorm:"column:psn_cert_type" json:"psn_cert_type" form:"psn_cert_type"`
	Certno                string    `gorm:"column:certno" json:"certno" form:"certno"`
	Gend                  string    `gorm:"column:gend" json:"gend" form:"gend"`
	Naty                  string    `gorm:"column:naty" json:"naty" form:"naty"`
	Brdy                  time.Time `gorm:"column:brdy" json:"brdy" form:"brdy"`
	Age                   float64   `gorm:"column:age" json:"age" form:"age"`
	Insutype              string    `gorm:"column:insutype" json:"insutype" form:"insutype"`
	PsnType               string    `gorm:"column:psn_type" json:"psn_type" form:"psn_type"`
	CvlservFlag           string    `gorm:"column:cvlserv_flag" json:"cvlserv_flag" form:"cvlserv_flag"`
	SetlTime              string    `gorm:"column:setl_time" json:"setl_time" form:"setl_time"`
	MdtrtCertType         string    `gorm:"column:mdtrt_cert_type" json:"mdtrt_cert_type" form:"mdtrt_cert_type"`
	MedType               string    `gorm:"column:med_type" json:"med_type" form:"med_type"`
	MedfeeSumamt          float64   `gorm:"column:medfee_sumamt" json:"medfee_sumamt" form:"medfee_sumamt"`
	FulamtOwnpayAmt       float64   `gorm:"column:fulamt_ownpay_amt" json:"fulamt_ownpay_amt" form:"fulamt_ownpay_amt"`
	OverlmtSelfPay        float64   `gorm:"column:overlmt_self_pay" json:"overlmt_self_pay" form:"overlmt_self_pay"`
	PreselfpayAmt         float64   `gorm:"column:preselfpay_amt" json:"preselfpay_amt" form:"preselfpay_amt"`
	InscpScpAmt           float64   `gorm:"column:inscp_scp_amt" json:"inscp_scp_amt" form:"inscp_scp_amt"`
	ActPayDedc            float64   `gorm:"column:act_pay_dedc" json:"act_pay_dedc" form:"act_pay_dedc"`
	HifpPay               float64   `gorm:"column:hifp_pay" json:"hifp_pay" form:"hifp_pay"`
	CvlservPay            float64   `gorm:"column:cvlserv_pay" json:"cvlserv_pay" form:"cvlserv_pay"`
	PoolPropSelfpay       float64   `gorm:"column:pool_prop_selfpay" json:"pool_prop_selfpay" form:"pool_prop_selfpay"`
	HifesPay              float64   `gorm:"column:hifes_pay" json:"hifes_pay" form:"hifes_pay"`
	HifmiPay              float64   `gorm:"column:hifmi_pay" json:"hifmi_pay" form:"hifmi_pay"`
	HifobPay              float64   `gorm:"column:hifob_pay" json:"hifob_pay" form:"hifob_pay"`
	MafPay                float64   `gorm:"column:maf_pay" json:"maf_pay" form:"maf_pay"`
	OthPay                float64   `gorm:"column:oth_pay" json:"oth_pay" form:"oth_pay"`
	FundPaySumamt         float64   `gorm:"column:fund_pay_sumamt" json:"fund_pay_sumamt" form:"fund_pay_sumamt"`
	PsnPartAmt            float64   `gorm:"column:psn_part_amt" json:"psn_part_amt" form:"psn_part_amt"`
	AcctPay               float64   `gorm:"column:acct_pay" json:"acct_pay" form:"acct_pay"`
	PsnCashPay            float64   `gorm:"column:psn_cash_pay" json:"psn_cash_pay" form:"psn_cash_pay"`
	HospPartAmt           float64   `gorm:"column:hosp_part_amt" json:"hosp_part_amt" form:"hosp_part_amt"`
	Balc                  float64   `gorm:"column:balc" json:"balc" form:"balc"`
	AcctMulaidPay         float64   `gorm:"column:acct_mulaid_pay" json:"acct_mulaid_pay" form:"acct_mulaid_pay"`
	MedinsSetlId          string    `gorm:"column:medins_setl_id" json:"medins_setl_id" form:"medins_setl_id"`
	ClrOptins             string    `gorm:"column:clr_optins" json:"clr_optins" form:"clr_optins"`
	ClrWay                string    `gorm:"column:clr_way" json:"clr_way" form:"clr_way"`
	ClrType               string    `gorm:"column:clr_type" json:"clr_type" form:"clr_type"`
	SetlDetail            string    `gorm:"column:setl_detail" json:"setl_detail" form:"setl_detail"`
	IsMedicineInsurance   int64     `gorm:"column:is_medicine_insurance" json:"is_medicine_insurance" form:"is_medicine_insurance"`
	PayWay                int64     `gorm:"column:pay_way" json:"pay_way" form:"pay_way"`
	PayPrice              float64   `gorm:"column:pay_price" json:"pay_price" form:"pay_price"`
	PayCardNo             string    `gorm:"column:pay_card_no" json:"pay_card_no" form:"pay_card_no"`
	DiscountPrice         float64   `gorm:"column:discount_price" json:"discount_price" form:"discount_price"`
	PreferentialPrice     float64   `gorm:"column:preferential_price" json:"preferential_price" form:"preferential_price"`
	RealityPrice          float64   `gorm:"column:reality_price" json:"reality_price" form:"reality_price"`
	FoundPrice            float64   `gorm:"column:found_price" json:"found_price" form:"found_price"`
	MedicalInsurancePrice float64   `gorm:"column:medical_insurance_price" json:"medical_insurance_price" form:"medical_insurance_price"`
	PrivatePrice          float64   `gorm:"column:private_price" json:"private_price" form:"private_price"`
	DepartmentName        string    `gorm:"-" json:"department_name" form:"department_name"`
	DoctorName            string    `gorm:"-" json:"doctor_name" form:"doctor_name"`
	SettleStartTime       int64     `gorm:"settle_start_time" json:"settle_start_time" form:"settle_start_time"`

	Creator            int64                 `gorm:"column:creator" json:"creator" form:"creator"`
	PType              int64                 `gorm:"column:p_type" json:"p_type" form:"p_type"`
	Decimal            float64               `gorm:"column:decimal" json:"decimal" form:"decimal"`
	VmHisOrderInfo9504 []*VmHisOrderInfo9504 `gorm:"ForeignKey:OrderNumber;AssociationForeignKey:Number" json:"info"`
	Patients           Patients              `gorm:"ForeignKey:PatientId;AssociationForeignKey:ID" json:"patient"`
}

func (HisOrder9504) TableName() string {
	return "his_order"
}

type VmHisOrderInfo9504 struct {
	ID                        int64                     `gorm:"column:id" json:"id" form:"id"`
	OrderNumber               string                    `gorm:"column:order_number" json:"order_number" form:"order_number"`
	UploadDate                int64                     `gorm:"column:upload_date" json:"upload_date" form:"upload_date"`
	AdviceId                  int64                     `gorm:"column:advice_id" json:"advice_id" form:"advice_id"`
	DetItemFeeSumamt          float64                   `gorm:"column:det_item_fee_sumamt" json:"det_item_fee_sumamt" form:"det_item_fee_sumamt"`
	Cnt                       float64                   `gorm:"column:cnt" json:"cnt" form:"cnt"`
	Pric                      float64                   `gorm:"column:pric" json:"pric" form:"pric"`
	PatientId                 int64                     `gorm:"column:patient_id" json:"patient_id" form:"patient_id"`
	PricUplmtAmt              float64                   `gorm:"column:pric_uplmt_amt" json:"pric_uplmt_amt" form:"pric_uplmt_amt"`
	SelfpayProp               float64                   `gorm:"column:selfpay_prop" json:"selfpay_prop" form:"selfpay_prop"`
	FulamtOwnpayAmt           float64                   `gorm:"column:fulamt_ownpay_amt" json:"fulamt_ownpay_amt" form:"fulamt_ownpay_amt"`
	OverlmtAmt                float64                   `gorm:"column:overlmt_amt" json:"overlmt_amt" form:"overlmt_amt"`
	PreselfpayAmt             float64                   `gorm:"column:preselfpay_amt" json:"preselfpay_amt" form:"preselfpay_amt"`
	BasMednFlag               string                    `gorm:"column:bas_medn_flag" json:"bas_medn_flag" form:"bas_medn_flag"`
	MedChrgitmType            string                    `gorm:"column:med_chrgitm_type" json:"med_chrgitm_type" form:"med_chrgitm_type"`
	HiNegoDrugFlag            string                    `gorm:"column:hi_nego_drug_flag" json:"hi_nego_drug_flag" form:"hi_nego_drug_flag"`
	Status                    int64                     `gorm:"column:status" json:"status" form:"status"`
	Memo                      string                    `gorm:"column:memo" json:"memo" form:"memo"`
	FeedetlSn                 string                    `gorm:"column:feedetl_sn" json:"feedetl_sn" form:"feedetl_sn"`
	Mtime                     int64                     `gorm:"column:mtime" json:"mtime" form:"mtime"`
	InscpScpAmt               float64                   `gorm:"column:inscp_scp_amt" json:"inscp_scp_amt" form:"inscp_scp_amt"`
	DrtReimFlag               string                    `gorm:"column:drt_reim_flag" json:"drt_reim_flag" form:"drt_reim_flag"`
	Ctime                     int64                     `gorm:"column:ctime" json:"ctime" form:"ctime"`
	ListSpItemFlag            string                    `gorm:"column:list_sp_item_flag" json:"list_sp_item_flag" form:"list_sp_item_flag"`
	ChldMedcFlag              string                    `gorm:"column:chld_medc_flag" json:"chld_medc_flag" form:"chld_medc_flag"`
	LmtUsedFlag               string                    `gorm:"column:lmt_used_flag" json:"lmt_used_flag" form:"lmt_used_flag"`
	ChrgitmLv                 string                    `gorm:"column:chrgitm_lv" json:"chrgitm_lv" form:"chrgitm_lv"`
	UserOrgId                 int64                     `gorm:"column:user_org_id" json:"user_org_id" form:"user_org_id"`
	HisPatientId              int64                     `gorm:"column:his_patient_id" json:"his_patient_id" form:"his_patient_id"`
	OrderId                   int64                     `gorm:"column:order_id" json:"order_id" form:"order_id"`
	ProjectId                 int64                     `gorm:"column:project_id" json:"project_id" form:"project_id"`
	Type                      int64                     `gorm:"column:type" json:"type" form:"type"`
	ItemId                    int64                     `gorm:"column:item_id" json:"item_id" form:"item_id"`
	SettleType                int64                     `gorm:"column:settle_type" json:"settle_type" form:"settle_type"`
	HisPrescriptionProjectTen HisPrescriptionProjectTen `gorm:"ForeignKey:ID;AssociationForeignKey:ProjectId" json:"project"`
	HisDoctorAdviceInfoTen    HisDoctorAdviceInfoTen    `gorm:"ForeignKey:ID;AssociationForeignKey:AdviceId" json:"advices"`
}

func (VmHisOrderInfo9504) TableName() string {
	return "his_order_info"
}

type VmHisOrderInfo95042 struct {
	ID               int64   `gorm:"column:id" json:"id" form:"id"`
	OrderNumber      string  `gorm:"column:order_number" json:"order_number" form:"order_number"`
	UploadDate       int64   `gorm:"column:upload_date" json:"upload_date" form:"upload_date"`
	AdviceId         int64   `gorm:"column:advice_id" json:"advice_id" form:"advice_id"`
	DetItemFeeSumamt float64 `gorm:"column:det_item_fee_sumamt" json:"det_item_fee_sumamt" form:"det_item_fee_sumamt"`
	Cnt              float64 `gorm:"column:cnt" json:"cnt" form:"cnt"`
	Pric             float64 `gorm:"column:pric" json:"pric" form:"pric"`
	PatientId        int64   `gorm:"column:patient_id" json:"patient_id" form:"patient_id"`
	PricUplmtAmt     float64 `gorm:"column:pric_uplmt_amt" json:"pric_uplmt_amt" form:"pric_uplmt_amt"`
	SelfpayProp      float64 `gorm:"column:selfpay_prop" json:"selfpay_prop" form:"selfpay_prop"`
	FulamtOwnpayAmt  float64 `gorm:"column:fulamt_ownpay_amt" json:"fulamt_ownpay_amt" form:"fulamt_ownpay_amt"`
	OverlmtAmt       float64 `gorm:"column:overlmt_amt" json:"overlmt_amt" form:"overlmt_amt"`
	PreselfpayAmt    float64 `gorm:"column:preselfpay_amt" json:"preselfpay_amt" form:"preselfpay_amt"`
	BasMednFlag      string  `gorm:"column:bas_medn_flag" json:"bas_medn_flag" form:"bas_medn_flag"`
	MedChrgitmType   string  `gorm:"column:med_chrgitm_type" json:"med_chrgitm_type" form:"med_chrgitm_type"`
	HiNegoDrugFlag   string  `gorm:"column:hi_nego_drug_flag" json:"hi_nego_drug_flag" form:"hi_nego_drug_flag"`
	Status           int64   `gorm:"column:status" json:"status" form:"status"`
	Memo             string  `gorm:"column:memo" json:"memo" form:"memo"`
	FeedetlSn        string  `gorm:"column:feedetl_sn" json:"feedetl_sn" form:"feedetl_sn"`
	Mtime            int64   `gorm:"column:mtime" json:"mtime" form:"mtime"`
	InscpScpAmt      float64 `gorm:"column:inscp_scp_amt" json:"inscp_scp_amt" form:"inscp_scp_amt"`
	DrtReimFlag      string  `gorm:"column:drt_reim_flag" json:"drt_reim_flag" form:"drt_reim_flag"`
	Ctime            int64   `gorm:"column:ctime" json:"ctime" form:"ctime"`
	ListSpItemFlag   string  `gorm:"column:list_sp_item_flag" json:"list_sp_item_flag" form:"list_sp_item_flag"`
	ChldMedcFlag     string  `gorm:"column:chld_medc_flag" json:"chld_medc_flag" form:"chld_medc_flag"`
	LmtUsedFlag      string  `gorm:"column:lmt_used_flag" json:"lmt_used_flag" form:"lmt_used_flag"`
	ChrgitmLv        string  `gorm:"column:chrgitm_lv" json:"chrgitm_lv" form:"chrgitm_lv"`
	UserOrgId        int64   `gorm:"column:user_org_id" json:"user_org_id" form:"user_org_id"`
	HisPatientId     int64   `gorm:"column:his_patient_id" json:"his_patient_id" form:"his_patient_id"`
	OrderId          int64   `gorm:"column:order_id" json:"order_id" form:"order_id"`
	ProjectId        int64   `gorm:"column:project_id" json:"project_id" form:"project_id"`
	Type             int64   `gorm:"column:type" json:"type" form:"type"`
	ItemId           int64   `gorm:"column:item_id" json:"item_id" form:"item_id"`
	SettleType       int64   `gorm:"column:settle_type" json:"settle_type" form:"settle_type"`
}

func (VmHisOrderInfo95042) TableName() string {
	return "his_order_info"
}

func GetHisOrderDetail9504() (order []*HisOrder9504, err error) {
	err = readDb.Model(&HisOrder9504{}).Preload("Patients", "status = 1").Preload("VmHisOrderInfo9504", func(db *gorm.DB) *gorm.DB {
		return db.Where("status = 1").Preload("HisPrescriptionProjectTen", func(db *gorm.DB) *gorm.DB {
			return db.Where("status = 1").Preload("VMHisProject", "status = 1").Preload("VMGoodInfo", "status = 1")
		}).Preload("HisDoctorAdviceInfoTen", func(db *gorm.DB) *gorm.DB {
			return db.Where("status = 1").Preload("Drug", "status = 1")
		})
	}).Where("settle_accounts_date >= 1640966400 AND settle_accounts_date <= 1661875200 AND status = 1 AND order_status =2  AND user_org_id = 9504").Find(&order).Order("setl_time").Error
	return
}

func GetHisOrderDetail10188() (order []*HisOrder9504, err error) {
	err = readDb.Model(&HisOrder9504{}).Preload("Patients", "status = 1").Preload("VmHisOrderInfo9504", func(db *gorm.DB) *gorm.DB {
		return db.Where("status = 1").Preload("HisPrescriptionProjectTen", func(db *gorm.DB) *gorm.DB {
			return db.Where("status = 1").Preload("VMHisProject", "status = 1").Preload("VMGoodInfo", "status = 1")
		})
	}).Where("settle_accounts_date >= 1654012800 AND settle_accounts_date <= 1661875200 AND status = 1 AND order_status =2  AND user_org_id = 10188").Find(&order).Order("setl_time").Error
	return
}

//func GetHisOrderDetail10138() (order []*HisOrder9504, err error) {
//	err = readDb.Model(&HisOrder9504{}).Preload("Patients", "status = 1").Preload("VmHisOrderInfo9504", func(db *gorm.DB) *gorm.DB {
//		return db.Where("status = 1").Preload("HisPrescriptionProjectTen", func(db *gorm.DB) *gorm.DB {
//			return db.Where("status = 1").Preload("VMHisProject", "status = 1")
//		})
//	}).Where("settle_accounts_date >= 1640966400 AND settle_accounts_date <= 1648656000 AND status = 1 AND order_status =2  AND user_org_id = 10138").Find(&order).Order("setl_time").Error
//	return
//}

func GetHisOrderDetail10138() (order []*HisOrderTen, err error) {
	err = readDb.Model(&HisOrderTen{}).Preload("HisPrescriptionTen", func(db *gorm.DB) *gorm.DB {
		return db.Where("status = 1 AND order_status = 2").Preload("HisPrescriptionProjectTen", func(db *gorm.DB) *gorm.DB {
			return db.Where("status = 1").Preload("VMHisProject")
		})
	}).Where("settle_accounts_date >= 1656604800 AND settle_accounts_date <= 1664553599 AND status = 1 AND order_status =2  AND user_org_id = 10138").Find(&order).Error
	return
}

func GetHisOrderDetail10265() (order_infos []*VmHisOrderInfo9504, err error) {
	err = readDb.Model(&VmHisOrderInfo9504{}).Preload("HisPrescriptionProjectTen", func(db *gorm.DB) *gorm.DB {
		return db.Preload("VMHisProject").Preload("VMGoodInfo", "status = 1")
	}).Preload("HisDoctorAdviceInfoTen", func(db *gorm.DB) *gorm.DB {
		return db.Where("status = 1").Preload("Drug", "status = 1")
	}).Where(" status = 1  AND user_org_id = 10265 AND order_number = '2022090814370516482'").Find(&order_infos).Error
	return
}

func GetHisOrder10265() (order_infos []*VmHisOrderInfo9504, err error) {
	err = readDb.Model(&VmHisOrderInfo95042{}).Where(" status = 1  AND user_org_id = 10265 AND order_number = '2022092912130116192' AND project_id > 0").Find(&order_infos).Error
	return
}

func SaveOrderInfo(info *VmHisOrderInfo9504) {
	writeDb.Save(&info)
}

func GetHisOrderDetail10106(start_time int64, end_time int64) (order []*HisOrder9504, err error) {
	err = readDb.Model(&HisOrder9504{}).Preload("VmHisOrderInfo9504", func(db *gorm.DB) *gorm.DB {
		return db.Where("status = 1").Preload("HisPrescriptionProjectTen", func(db *gorm.DB) *gorm.DB {
			return db.Where("status = 1").Preload("VMHisProject").Preload("VMGoodInfo")
		}).Preload("HisDoctorAdviceInfoTen", func(db *gorm.DB) *gorm.DB {
			return db.Where("status = 1").Preload("Drug")
		})
	}).Where("settle_accounts_date >= ? AND settle_accounts_date <= ? AND status = 1 AND order_status =2  AND user_org_id = 10106", start_time, end_time).Find(&order).Order("setl_time").Error
	return
}

func GetLongSolution() {
	records, _ := GetAllSchedules()
	fmt.Println(records)
	for _, item := range records {
		//1.透析器   2.灌流器     3.透析器/灌流器
		so, _ := GetDialysisSolutionTwo(item.UserOrgId, item.PatientId, item.ModeId)
		filedRecordOne, _ := FindFiledBy(item.UserOrgId, "透析器")
		filedRecordTwo, _ := FindFiledBy(item.UserOrgId, "灌流器")
		filedRecordThree, _ := FindFiledBy(item.UserOrgId, "透析器/灌流器")
		if filedRecordOne.IsShow == 1 {
			item.DialysisMachineName = so.DialysisDialyszers
		}
		if filedRecordThree.IsShow == 1 {
			if len(item.DialysisMachineName) > 0 {
				item.DialysisMachineName = item.DialysisMachineName + "," + so.DialyzerPerfusionApparatus

			} else {
				item.DialysisMachineName = so.DialyzerPerfusionApparatus

			}
		}
		if filedRecordTwo.IsShow == 1 {
			if len(item.DialysisMachineName) > 0 {
				item.DialysisMachineName = item.DialysisMachineName + "," + so.DialysisIrrigation

			} else {
				item.DialysisMachineName = so.DialysisIrrigation

			}
		}

		UpdateSch(item)

	}
}

func GetAllSchMode() (modes []*models.PatientScheduleTemplateMode, getModesErr error) {
	getModesErr = readDb.Model(&models.PatientScheduleTemplateMode{}).Where("mode <> 0 AND status = 1 ").Find(&modes).Error
	return
}

type DialysisSolutionTwo struct {
	ID        int64 `gorm:"column:id" json:"id" form:"id"`
	UserOrgId int64 `gorm:"column:user_org_id" json:"user_org_id" form:"user_org_id"`
}

func (DialysisSolutionTwo) TableName() string {
	return "xt_dialysis_solution"
}

type Schedule struct {
	ID                  int64  `gorm:"column:id" json:"id" form:"id"`
	UserOrgId           int64  `gorm:"column:user_org_id" json:"user_org_id" form:"user_org_id"`
	PatientId           int64  `gorm:"column:patient_id" json:"patient_id" form:"patient_id"`
	Status              int64  `gorm:"column:status" json:"status" form:"status"`
	ScheduleDate        int64  `gorm:"column:schedule_date" json:"schedule_date" form:"schedule_date"`
	ModeId              int64  `gorm:"column:mode_id" json:"mode_id" form:"mode_id"`
	DialysisMachineName string `gorm:"column:dialysis_machine_name" json:"dialysis_machine_name" form:"dialysis_machine_name"`
}

func (Schedule) TableName() string {
	return "xt_schedule"
}

func GetAllSchedules() ([]Schedule, error) {
	var record []Schedule

	err := readDb.Model(&Schedule{}).Where("status = 1 AND schedule_date > 1670774400").Find(&record).Error
	if err != nil {
		if err == gorm.ErrRecordNotFound {
			return nil, nil
		} else {
			return nil, err
		}
	}
	return record, nil
}

func FindFiledBy(org_id int64, name string) (filedConfig models.FiledConfig, err error) {
	err = readDb.Model(&models.FiledConfig{}).Where("org_id =? AND  module = 1 AND filed_name_cn= ?", org_id, name).First(&filedConfig).Error
	return
}

// 透析方案
func GetDialysisSolutionTwo(orgID int64, patientID int64, mode_id int64) (models.DialysisSolution, error) {
	var record models.DialysisSolution
	err := readDb.Model(&models.DialysisSolution{}).Where("patient_id = ? and user_org_id = ? and status = 1 AND mode_id = ?", patientID, orgID, mode_id).Last(&record).Error
	return record, err
}

func UpdateSch(sch Schedule) (err error) {
	err = writeDb.Model(&Schedule{}).Where("status=1 AND id = ?", sch.ID).Updates(map[string]interface{}{"dialysis_machine_name": sch.DialysisMachineName}).Error
	return
}

func SaveSch(sch models.Schedule) (err error) {
	err = writeDb.Save(&sch).Error
	return
}
